# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Comprehend Medical'
prefix = 'comprehendmedical'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DescribeEntitiesDetectionV2Job = Action('DescribeEntitiesDetectionV2Job')
DescribeICD10CMInferenceJob = Action('DescribeICD10CMInferenceJob')
DescribePHIDetectionJob = Action('DescribePHIDetectionJob')
DescribeRxNormInferenceJob = Action('DescribeRxNormInferenceJob')
DetectEntities = Action('DetectEntities')
DetectEntitiesV2 = Action('DetectEntitiesV2')
DetectPHI = Action('DetectPHI')
InferICD10CM = Action('InferICD10CM')
InferRxNorm = Action('InferRxNorm')
ListEntitiesDetectionV2Jobs = Action('ListEntitiesDetectionV2Jobs')
ListICD10CMInferenceJobs = Action('ListICD10CMInferenceJobs')
ListPHIDetectionJobs = Action('ListPHIDetectionJobs')
ListRxNormInferenceJobs = Action('ListRxNormInferenceJobs')
StartEntitiesDetectionV2Job = Action('StartEntitiesDetectionV2Job')
StartICD10CMInferenceJob = Action('StartICD10CMInferenceJob')
StartPHIDetectionJob = Action('StartPHIDetectionJob')
StartRxNormInferenceJob = Action('StartRxNormInferenceJob')
StopEntitiesDetectionV2Job = Action('StopEntitiesDetectionV2Job')
StopICD10CMInferenceJob = Action('StopICD10CMInferenceJob')
StopPHIDetectionJob = Action('StopPHIDetectionJob')
StopRxNormInferenceJob = Action('StopRxNormInferenceJob')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Audit Manager'
prefix = 'auditmanager'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateAssessmentReportEvidenceFolder = \
    Action('AssociateAssessmentReportEvidenceFolder')
BatchAssociateAssessmentReportEvidence = \
    Action('BatchAssociateAssessmentReportEvidence')
BatchCreateDelegationByAssessment = \
    Action('BatchCreateDelegationByAssessment')
BatchDeleteDelegationByAssessment = \
    Action('BatchDeleteDelegationByAssessment')
BatchDisassociateAssessmentReportEvidence = \
    Action('BatchDisassociateAssessmentReportEvidence')
BatchImportEvidenceToAssessmentControl = \
    Action('BatchImportEvidenceToAssessmentControl')
CreateAssessment = Action('CreateAssessment')
CreateAssessmentFramework = Action('CreateAssessmentFramework')
CreateAssessmentReport = Action('CreateAssessmentReport')
CreateControl = Action('CreateControl')
DeleteAssessment = Action('DeleteAssessment')
DeleteAssessmentFramework = Action('DeleteAssessmentFramework')
DeleteAssessmentReport = Action('DeleteAssessmentReport')
DeleteControl = Action('DeleteControl')
DeregisterAccount = Action('DeregisterAccount')
DeregisterOrganizationAdminAccount = \
    Action('DeregisterOrganizationAdminAccount')
DisassociateAssessmentReportEvidenceFolder = \
    Action('DisassociateAssessmentReportEvidenceFolder')
GetAccountStatus = Action('GetAccountStatus')
GetAssessment = Action('GetAssessment')
GetAssessmentFramework = Action('GetAssessmentFramework')
GetAssessmentReportUrl = Action('GetAssessmentReportUrl')
GetChangeLogs = Action('GetChangeLogs')
GetControl = Action('GetControl')
GetDelegations = Action('GetDelegations')
GetEvidence = Action('GetEvidence')
GetEvidenceByEvidenceFolder = Action('GetEvidenceByEvidenceFolder')
GetEvidenceFolder = Action('GetEvidenceFolder')
GetEvidenceFoldersByAssessment = Action('GetEvidenceFoldersByAssessment')
GetEvidenceFoldersByAssessmentControl = \
    Action('GetEvidenceFoldersByAssessmentControl')
GetOrganizationAdminAccount = Action('GetOrganizationAdminAccount')
GetServicesInScope = Action('GetServicesInScope')
GetSettings = Action('GetSettings')
ListAssessmentFrameworks = Action('ListAssessmentFrameworks')
ListAssessmentReports = Action('ListAssessmentReports')
ListAssessments = Action('ListAssessments')
ListControls = Action('ListControls')
ListKeywordsForDataSource = Action('ListKeywordsForDataSource')
ListNotifications = Action('ListNotifications')
ListTagsForResource = Action('ListTagsForResource')
RegisterAccount = Action('RegisterAccount')
RegisterOrganizationAdminAccount = \
    Action('RegisterOrganizationAdminAccount')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAssessment = Action('UpdateAssessment')
UpdateAssessmentControl = Action('UpdateAssessmentControl')
UpdateAssessmentControlSetStatus = \
    Action('UpdateAssessmentControlSetStatus')
UpdateAssessmentFramework = Action('UpdateAssessmentFramework')
UpdateAssessmentStatus = Action('UpdateAssessmentStatus')
UpdateControl = Action('UpdateControl')
UpdateSettings = Action('UpdateSettings')
ValidateAssessmentReportIntegrity = \
    Action('ValidateAssessmentReportIntegrity')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Compute Optimizer'
prefix = 'compute-optimizer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DescribeRecommendationExportJobs = \
    Action('DescribeRecommendationExportJobs')
ExportAutoScalingGroupRecommendations = \
    Action('ExportAutoScalingGroupRecommendations')
ExportEC2InstanceRecommendations = \
    Action('ExportEC2InstanceRecommendations')
GetAutoScalingGroupRecommendations = \
    Action('GetAutoScalingGroupRecommendations')
GetEBSVolumeRecommendations = Action('GetEBSVolumeRecommendations')
GetEC2InstanceRecommendations = Action('GetEC2InstanceRecommendations')
GetEC2RecommendationProjectedMetrics = \
    Action('GetEC2RecommendationProjectedMetrics')
GetEnrollmentStatus = Action('GetEnrollmentStatus')
GetLambdaFunctionRecommendations = \
    Action('GetLambdaFunctionRecommendations')
GetRecommendationSummaries = Action('GetRecommendationSummaries')
UpdateEnrollmentStatus = Action('UpdateEnrollmentStatus')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon EventBridge Schemas'
prefix = 'schemas'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateDiscoverer = Action('CreateDiscoverer')
CreateRegistry = Action('CreateRegistry')
CreateSchema = Action('CreateSchema')
DeleteDiscoverer = Action('DeleteDiscoverer')
DeleteRegistry = Action('DeleteRegistry')
DeleteResourcePolicy = Action('DeleteResourcePolicy')
DeleteSchema = Action('DeleteSchema')
DeleteSchemaVersion = Action('DeleteSchemaVersion')
DescribeCodeBinding = Action('DescribeCodeBinding')
DescribeDiscoverer = Action('DescribeDiscoverer')
DescribeRegistry = Action('DescribeRegistry')
DescribeSchema = Action('DescribeSchema')
ExportSchema = Action('ExportSchema')
GetCodeBindingSource = Action('GetCodeBindingSource')
GetDiscoveredSchema = Action('GetDiscoveredSchema')
GetResourcePolicy = Action('GetResourcePolicy')
ListDiscoverers = Action('ListDiscoverers')
ListRegistries = Action('ListRegistries')
ListSchemaVersions = Action('ListSchemaVersions')
ListSchemas = Action('ListSchemas')
ListTagsForResource = Action('ListTagsForResource')
PutCodeBinding = Action('PutCodeBinding')
PutResourcePolicy = Action('PutResourcePolicy')
SearchSchemas = Action('SearchSchemas')
StartDiscoverer = Action('StartDiscoverer')
StopDiscoverer = Action('StopDiscoverer')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDiscoverer = Action('UpdateDiscoverer')
UpdateRegistry = Action('UpdateRegistry')
UpdateSchema = Action('UpdateSchema')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Proton'
prefix = 'proton'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateEnvironment = Action('CreateEnvironment')
CreateEnvironmentTemplate = Action('CreateEnvironmentTemplate')
CreateEnvironmentTemplateMajorVersion = \
    Action('CreateEnvironmentTemplateMajorVersion')
CreateEnvironmentTemplateMinorVersion = \
    Action('CreateEnvironmentTemplateMinorVersion')
CreateService = Action('CreateService')
CreateServiceTemplate = Action('CreateServiceTemplate')
CreateServiceTemplateMajorVersion = \
    Action('CreateServiceTemplateMajorVersion')
CreateServiceTemplateMinorVersion = \
    Action('CreateServiceTemplateMinorVersion')
DeleteAccountRoles = Action('DeleteAccountRoles')
DeleteEnvironment = Action('DeleteEnvironment')
DeleteEnvironmentTemplate = Action('DeleteEnvironmentTemplate')
DeleteEnvironmentTemplateMajorVersion = \
    Action('DeleteEnvironmentTemplateMajorVersion')
DeleteEnvironmentTemplateMinorVersion = \
    Action('DeleteEnvironmentTemplateMinorVersion')
DeleteService = Action('DeleteService')
DeleteServiceTemplate = Action('DeleteServiceTemplate')
DeleteServiceTemplateMajorVersion = \
    Action('DeleteServiceTemplateMajorVersion')
DeleteServiceTemplateMinorVersion = \
    Action('DeleteServiceTemplateMinorVersion')
GetAccountRoles = Action('GetAccountRoles')
GetEnvironment = Action('GetEnvironment')
GetEnvironmentTemplate = Action('GetEnvironmentTemplate')
GetEnvironmentTemplateMajorVersion = \
    Action('GetEnvironmentTemplateMajorVersion')
GetEnvironmentTemplateMinorVersion = \
    Action('GetEnvironmentTemplateMinorVersion')
GetService = Action('GetService')
GetServiceInstance = Action('GetServiceInstance')
GetServiceTemplate = Action('GetServiceTemplate')
GetServiceTemplateMajorVersion = Action('GetServiceTemplateMajorVersion')
GetServiceTemplateMinorVersion = Action('GetServiceTemplateMinorVersion')
ListEnvironmentTemplateMajorVersions = \
    Action('ListEnvironmentTemplateMajorVersions')
ListEnvironmentTemplateMinorVersions = \
    Action('ListEnvironmentTemplateMinorVersions')
ListEnvironmentTemplates = Action('ListEnvironmentTemplates')
ListEnvironments = Action('ListEnvironments')
ListServiceInstances = Action('ListServiceInstances')
ListServiceTemplateMajorVersions = \
    Action('ListServiceTemplateMajorVersions')
ListServiceTemplateMinorVersions = \
    Action('ListServiceTemplateMinorVersions')
ListServiceTemplates = Action('ListServiceTemplates')
ListServices = Action('ListServices')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAccountRoles = Action('UpdateAccountRoles')
UpdateEnvironment = Action('UpdateEnvironment')
UpdateEnvironmentTemplate = Action('UpdateEnvironmentTemplate')
UpdateEnvironmentTemplateMajorVersion = \
    Action('UpdateEnvironmentTemplateMajorVersion')
UpdateEnvironmentTemplateMinorVersion = \
    Action('UpdateEnvironmentTemplateMinorVersion')
UpdateService = Action('UpdateService')
UpdateServiceInstance = Action('UpdateServiceInstance')
UpdateServicePipeline = Action('UpdateServicePipeline')
UpdateServiceTemplate = Action('UpdateServiceTemplate')
UpdateServiceTemplateMajorVersion = \
    Action('UpdateServiceTemplateMajorVersion')
UpdateServiceTemplateMinorVersion = \
    Action('UpdateServiceTemplateMinorVersion')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon EventBridge'
prefix = 'events'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ActivateEventSource = Action('ActivateEventSource')
CancelReplay = Action('CancelReplay')
CreateApiDestination = Action('CreateApiDestination')
CreateArchive = Action('CreateArchive')
CreateConnection = Action('CreateConnection')
CreateEventBus = Action('CreateEventBus')
CreatePartnerEventSource = Action('CreatePartnerEventSource')
DeactivateEventSource = Action('DeactivateEventSource')
DeauthorizeConnection = Action('DeauthorizeConnection')
DeleteApiDestination = Action('DeleteApiDestination')
DeleteArchive = Action('DeleteArchive')
DeleteConnection = Action('DeleteConnection')
DeleteEventBus = Action('DeleteEventBus')
DeletePartnerEventSource = Action('DeletePartnerEventSource')
DeleteRule = Action('DeleteRule')
DescribeApiDestination = Action('DescribeApiDestination')
DescribeArchive = Action('DescribeArchive')
DescribeConnection = Action('DescribeConnection')
DescribeEventBus = Action('DescribeEventBus')
DescribeEventSource = Action('DescribeEventSource')
DescribePartnerEventSource = Action('DescribePartnerEventSource')
DescribeReplay = Action('DescribeReplay')
DescribeRule = Action('DescribeRule')
DisableRule = Action('DisableRule')
EnableRule = Action('EnableRule')
InvokeApiDestination = Action('InvokeApiDestination')
ListApiDestinations = Action('ListApiDestinations')
ListArchives = Action('ListArchives')
ListConnections = Action('ListConnections')
ListEventBuses = Action('ListEventBuses')
ListEventSources = Action('ListEventSources')
ListPartnerEventSourceAccounts = Action('ListPartnerEventSourceAccounts')
ListPartnerEventSources = Action('ListPartnerEventSources')
ListReplays = Action('ListReplays')
ListRuleNamesByTarget = Action('ListRuleNamesByTarget')
ListRules = Action('ListRules')
ListTagsForResource = Action('ListTagsForResource')
ListTargetsByRule = Action('ListTargetsByRule')
PutEvents = Action('PutEvents')
PutPartnerEvents = Action('PutPartnerEvents')
PutPermission = Action('PutPermission')
PutRule = Action('PutRule')
PutTargets = Action('PutTargets')
RemovePermission = Action('RemovePermission')
RemoveTargets = Action('RemoveTargets')
StartReplay = Action('StartReplay')
TagResource = Action('TagResource')
TestEventPattern = Action('TestEventPattern')
UntagResource = Action('UntagResource')
UpdateApiDestination = Action('UpdateApiDestination')
UpdateArchive = Action('UpdateArchive')
UpdateConnection = Action('UpdateConnection')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Kinesis Video Streams'
prefix = 'kinesisvideo'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ConnectAsMaster = Action('ConnectAsMaster')
ConnectAsViewer = Action('ConnectAsViewer')
CreateSignalingChannel = Action('CreateSignalingChannel')
CreateStream = Action('CreateStream')
DeleteSignalingChannel = Action('DeleteSignalingChannel')
DeleteStream = Action('DeleteStream')
DescribeSignalingChannel = Action('DescribeSignalingChannel')
DescribeStream = Action('DescribeStream')
GetClip = Action('GetClip')
GetDASHStreamingSessionURL = Action('GetDASHStreamingSessionURL')
GetDataEndpoint = Action('GetDataEndpoint')
GetHLSStreamingSessionURL = Action('GetHLSStreamingSessionURL')
GetIceServerConfig = Action('GetIceServerConfig')
GetMedia = Action('GetMedia')
GetMediaForFragmentList = Action('GetMediaForFragmentList')
GetSignalingChannelEndpoint = Action('GetSignalingChannelEndpoint')
ListFragments = Action('ListFragments')
ListSignalingChannels = Action('ListSignalingChannels')
ListStreams = Action('ListStreams')
ListTagsForResource = Action('ListTagsForResource')
ListTagsForStream = Action('ListTagsForStream')
PutMedia = Action('PutMedia')
SendAlexaOfferToMaster = Action('SendAlexaOfferToMaster')
TagResource = Action('TagResource')
TagStream = Action('TagStream')
UntagResource = Action('UntagResource')
UntagStream = Action('UntagStream')
UpdateDataRetention = Action('UpdateDataRetention')
UpdateSignalingChannel = Action('UpdateSignalingChannel')
UpdateStream = Action('UpdateStream')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'CloudWatch Application Insights'
prefix = 'applicationinsights'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApplication = Action('CreateApplication')
CreateComponent = Action('CreateComponent')
CreateLogPattern = Action('CreateLogPattern')
DeleteApplication = Action('DeleteApplication')
DeleteComponent = Action('DeleteComponent')
DeleteLogPattern = Action('DeleteLogPattern')
DescribeApplication = Action('DescribeApplication')
DescribeComponent = Action('DescribeComponent')
DescribeComponentConfiguration = Action('DescribeComponentConfiguration')
DescribeComponentConfigurationRecommendation = \
    Action('DescribeComponentConfigurationRecommendation')
DescribeLogPattern = Action('DescribeLogPattern')
DescribeObservation = Action('DescribeObservation')
DescribeProblem = Action('DescribeProblem')
DescribeProblemObservations = Action('DescribeProblemObservations')
ListApplications = Action('ListApplications')
ListComponents = Action('ListComponents')
ListConfigurationHistory = Action('ListConfigurationHistory')
ListLogPatternSets = Action('ListLogPatternSets')
ListLogPatterns = Action('ListLogPatterns')
ListProblems = Action('ListProblems')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateApplication = Action('UpdateApplication')
UpdateComponent = Action('UpdateComponent')
UpdateComponentConfiguration = Action('UpdateComponentConfiguration')
UpdateLogPattern = Action('UpdateLogPattern')



import os
from setuptools import setup, find_packages

# ----------------------------------------------------------------------------
# Helper Functions
# ----------------------------------------------------------------------------


def file_contents(file_name):
    """Given a file name to a valid file returns the file object."""
    curr_dir = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(curr_dir, file_name)) as the_file:
        contents = the_file.read()
    return contents


def get_version():
    curr_dir = os.path.abspath(os.path.dirname(__file__))
    with open(curr_dir + "/awacs/__init__.py", "r") as init_version:
        for line in init_version:
            if "__version__" in line:
                return str(line.split("=")[-1].strip(" ")[1:-2])

# ----------------------------------------------------------------------------
# Setup
# ----------------------------------------------------------------------------


setup(
    name='awacs',
    version=get_version(),
    description="AWS Access Policy Language creation library",
    long_description=file_contents("README.rst"),
    long_description_content_type='text/x-rst',

    author="Mark Peek",
    author_email="mark@peek.org",
    url="https://github.com/cloudtools/awacs",
    license="New BSD license",
    packages=find_packages(),
    test_suite="tests",
    use_2to3=True,
    requires=['slimit'],
    python_requires=(
        ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*, !=3.5.*"
    ),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",

        "License :: OSI Approved :: BSD License",

        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: BSD",
        "Operating System :: POSIX :: Linux",

        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 2.7",
    ],
)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Timestream'
prefix = 'timestream'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelQuery = Action('CancelQuery')
CreateDatabase = Action('CreateDatabase')
CreateTable = Action('CreateTable')
DeleteDatabase = Action('DeleteDatabase')
DeleteTable = Action('DeleteTable')
DescribeDatabase = Action('DescribeDatabase')
DescribeEndpoints = Action('DescribeEndpoints')
DescribeTable = Action('DescribeTable')
ListDatabases = Action('ListDatabases')
ListMeasures = Action('ListMeasures')
ListTables = Action('ListTables')
ListTagsForResource = Action('ListTagsForResource')
Select = Action('Select')
SelectValues = Action('SelectValues')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDatabase = Action('UpdateDatabase')
UpdateTable = Action('UpdateTable')
WriteRecords = Action('WriteRecords')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS WAF V2'
prefix = 'wafv2'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateWebACL = Action('AssociateWebACL')
CheckCapacity = Action('CheckCapacity')
CreateIPSet = Action('CreateIPSet')
CreateRegexPatternSet = Action('CreateRegexPatternSet')
CreateRuleGroup = Action('CreateRuleGroup')
CreateWebACL = Action('CreateWebACL')
DeleteFirewallManagerRuleGroups = \
    Action('DeleteFirewallManagerRuleGroups')
DeleteIPSet = Action('DeleteIPSet')
DeleteLoggingConfiguration = Action('DeleteLoggingConfiguration')
DeletePermissionPolicy = Action('DeletePermissionPolicy')
DeleteRegexPatternSet = Action('DeleteRegexPatternSet')
DeleteRuleGroup = Action('DeleteRuleGroup')
DeleteWebACL = Action('DeleteWebACL')
DescribeManagedRuleGroup = Action('DescribeManagedRuleGroup')
DisassociateFirewallManager = Action('DisassociateFirewallManager')
DisassociateWebACL = Action('DisassociateWebACL')
GetIPSet = Action('GetIPSet')
GetLoggingConfiguration = Action('GetLoggingConfiguration')
GetPermissionPolicy = Action('GetPermissionPolicy')
GetRateBasedStatementManagedKeys = \
    Action('GetRateBasedStatementManagedKeys')
GetRegexPatternSet = Action('GetRegexPatternSet')
GetRuleGroup = Action('GetRuleGroup')
GetSampledRequests = Action('GetSampledRequests')
GetWebACL = Action('GetWebACL')
GetWebACLForResource = Action('GetWebACLForResource')
ListAvailableManagedRuleGroups = Action('ListAvailableManagedRuleGroups')
ListIPSets = Action('ListIPSets')
ListLoggingConfigurations = Action('ListLoggingConfigurations')
ListRegexPatternSets = Action('ListRegexPatternSets')
ListResourcesForWebACL = Action('ListResourcesForWebACL')
ListRuleGroups = Action('ListRuleGroups')
ListTagsForResource = Action('ListTagsForResource')
ListWebACLs = Action('ListWebACLs')
PutFirewallManagerRuleGroups = Action('PutFirewallManagerRuleGroups')
PutLoggingConfiguration = Action('PutLoggingConfiguration')
PutPermissionPolicy = Action('PutPermissionPolicy')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateIPSet = Action('UpdateIPSet')
UpdateRegexPatternSet = Action('UpdateRegexPatternSet')
UpdateRuleGroup = Action('UpdateRuleGroup')
UpdateWebACL = Action('UpdateWebACL')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental Appliances and Software Activation Service'
prefix = 'elemental-activations'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CompleteAccountRegistration = Action('CompleteAccountRegistration')
CompleteFileUpload = Action('CompleteFileUpload')
DownloadSoftware = Action('DownloadSoftware')
GenerateLicenses = Action('GenerateLicenses')
GetActivation = Action('GetActivation')
ListTagsForResource = Action('ListTagsForResource')
StartAccountRegistration = Action('StartAccountRegistration')
StartFileUpload = Action('StartFileUpload')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IAM Access Analyzer'
prefix = 'access-analyzer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ApplyArchiveRule = Action('ApplyArchiveRule')
CreateAccessPreview = Action('CreateAccessPreview')
CreateAnalyzer = Action('CreateAnalyzer')
CreateArchiveRule = Action('CreateArchiveRule')
DeleteAnalyzer = Action('DeleteAnalyzer')
DeleteArchiveRule = Action('DeleteArchiveRule')
GetAccessPreview = Action('GetAccessPreview')
GetAnalyzedResource = Action('GetAnalyzedResource')
GetAnalyzer = Action('GetAnalyzer')
GetArchiveRule = Action('GetArchiveRule')
GetFinding = Action('GetFinding')
ListAccessPreviewFindings = Action('ListAccessPreviewFindings')
ListAccessPreviews = Action('ListAccessPreviews')
ListAnalyzedResources = Action('ListAnalyzedResources')
ListAnalyzers = Action('ListAnalyzers')
ListArchiveRules = Action('ListArchiveRules')
ListFindings = Action('ListFindings')
ListTagsForResource = Action('ListTagsForResource')
StartResourceScan = Action('StartResourceScan')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateArchiveRule = Action('UpdateArchiveRule')
UpdateFindings = Action('UpdateFindings')
ValidatePolicy = Action('ValidatePolicy')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Comprehend'
prefix = 'comprehend'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDetectDominantLanguage = Action('BatchDetectDominantLanguage')
BatchDetectEntities = Action('BatchDetectEntities')
BatchDetectKeyPhrases = Action('BatchDetectKeyPhrases')
BatchDetectSentiment = Action('BatchDetectSentiment')
BatchDetectSyntax = Action('BatchDetectSyntax')
ClassifyDocument = Action('ClassifyDocument')
ContainsPiiEntities = Action('ContainsPiiEntities')
CreateDocumentClassifier = Action('CreateDocumentClassifier')
CreateEndpoint = Action('CreateEndpoint')
CreateEntityRecognizer = Action('CreateEntityRecognizer')
DeleteDocumentClassifier = Action('DeleteDocumentClassifier')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteEntityRecognizer = Action('DeleteEntityRecognizer')
DescribeDocumentClassificationJob = \
    Action('DescribeDocumentClassificationJob')
DescribeDocumentClassifier = Action('DescribeDocumentClassifier')
DescribeDominantLanguageDetectionJob = \
    Action('DescribeDominantLanguageDetectionJob')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeEntitiesDetectionJob = Action('DescribeEntitiesDetectionJob')
DescribeEntityRecognizer = Action('DescribeEntityRecognizer')
DescribeEventsDetectionJob = Action('DescribeEventsDetectionJob')
DescribeKeyPhrasesDetectionJob = Action('DescribeKeyPhrasesDetectionJob')
DescribePiiEntitiesDetectionJob = \
    Action('DescribePiiEntitiesDetectionJob')
DescribeSentimentDetectionJob = Action('DescribeSentimentDetectionJob')
DescribeTopicsDetectionJob = Action('DescribeTopicsDetectionJob')
DetectDominantLanguage = Action('DetectDominantLanguage')
DetectEntities = Action('DetectEntities')
DetectKeyPhrases = Action('DetectKeyPhrases')
DetectPiiEntities = Action('DetectPiiEntities')
DetectSentiment = Action('DetectSentiment')
DetectSyntax = Action('DetectSyntax')
ListDocumentClassificationJobs = Action('ListDocumentClassificationJobs')
ListDocumentClassifiers = Action('ListDocumentClassifiers')
ListDominantLanguageDetectionJobs = \
    Action('ListDominantLanguageDetectionJobs')
ListEndpoints = Action('ListEndpoints')
ListEntitiesDetectionJobs = Action('ListEntitiesDetectionJobs')
ListEntityRecognizers = Action('ListEntityRecognizers')
ListEventsDetectionJobs = Action('ListEventsDetectionJobs')
ListKeyPhrasesDetectionJobs = Action('ListKeyPhrasesDetectionJobs')
ListPiiEntitiesDetectionJobs = Action('ListPiiEntitiesDetectionJobs')
ListSentimentDetectionJobs = Action('ListSentimentDetectionJobs')
ListTagsForResource = Action('ListTagsForResource')
ListTopicsDetectionJobs = Action('ListTopicsDetectionJobs')
StartDocumentClassificationJob = Action('StartDocumentClassificationJob')
StartDominantLanguageDetectionJob = \
    Action('StartDominantLanguageDetectionJob')
StartEntitiesDetectionJob = Action('StartEntitiesDetectionJob')
StartEventsDetectionJob = Action('StartEventsDetectionJob')
StartKeyPhrasesDetectionJob = Action('StartKeyPhrasesDetectionJob')
StartPiiEntitiesDetectionJob = Action('StartPiiEntitiesDetectionJob')
StartSentimentDetectionJob = Action('StartSentimentDetectionJob')
StartTopicsDetectionJob = Action('StartTopicsDetectionJob')
StopDominantLanguageDetectionJob = \
    Action('StopDominantLanguageDetectionJob')
StopEntitiesDetectionJob = Action('StopEntitiesDetectionJob')
StopEventsDetectionJob = Action('StopEventsDetectionJob')
StopKeyPhrasesDetectionJob = Action('StopKeyPhrasesDetectionJob')
StopPiiEntitiesDetectionJob = Action('StopPiiEntitiesDetectionJob')
StopSentimentDetectionJob = Action('StopSentimentDetectionJob')
StopTrainingDocumentClassifier = Action('StopTrainingDocumentClassifier')
StopTrainingEntityRecognizer = Action('StopTrainingEntityRecognizer')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateEndpoint = Action('UpdateEndpoint')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Honeycode'
prefix = 'honeycode'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ApproveTeamAssociation = Action('ApproveTeamAssociation')
BatchCreateTableRows = Action('BatchCreateTableRows')
BatchDeleteTableRows = Action('BatchDeleteTableRows')
BatchUpdateTableRows = Action('BatchUpdateTableRows')
BatchUpsertTableRows = Action('BatchUpsertTableRows')
CreateTenant = Action('CreateTenant')
DescribeTableDataImportJob = Action('DescribeTableDataImportJob')
GetScreenData = Action('GetScreenData')
InvokeScreenAutomation = Action('InvokeScreenAutomation')
ListTableColumns = Action('ListTableColumns')
ListTableRows = Action('ListTableRows')
ListTables = Action('ListTables')
ListTeamAssociations = Action('ListTeamAssociations')
ListTenants = Action('ListTenants')
QueryTableRows = Action('QueryTableRows')
RejectTeamAssociation = Action('RejectTeamAssociation')
StartTableDataImportJob = Action('StartTableDataImportJob')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Kendra'
prefix = 'kendra'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDeleteDocument = Action('BatchDeleteDocument')
BatchPutDocument = Action('BatchPutDocument')
CreateDataSource = Action('CreateDataSource')
CreateFaq = Action('CreateFaq')
CreateIndex = Action('CreateIndex')
CreateThesaurus = Action('CreateThesaurus')
DeleteDataSource = Action('DeleteDataSource')
DeleteFaq = Action('DeleteFaq')
DeleteIndex = Action('DeleteIndex')
DeleteThesaurus = Action('DeleteThesaurus')
DescribeDataSource = Action('DescribeDataSource')
DescribeFaq = Action('DescribeFaq')
DescribeIndex = Action('DescribeIndex')
DescribeThesaurus = Action('DescribeThesaurus')
ListDataSourceSyncJobs = Action('ListDataSourceSyncJobs')
ListDataSources = Action('ListDataSources')
ListFaqs = Action('ListFaqs')
ListIndices = Action('ListIndices')
ListTagsForResource = Action('ListTagsForResource')
ListThesauri = Action('ListThesauri')
Query = Action('Query')
StartDataSourceSyncJob = Action('StartDataSourceSyncJob')
StopDataSourceSyncJob = Action('StopDataSourceSyncJob')
SubmitFeedback = Action('SubmitFeedback')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDataSource = Action('UpdateDataSource')
UpdateIndex = Action('UpdateIndex')
UpdateThesaurus = Action('UpdateThesaurus')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeStar Notifications'
prefix = 'codestar-notifications'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateNotificationRule = Action('CreateNotificationRule')
DeleteNotificationRule = Action('DeleteNotificationRule')
DeleteTarget = Action('DeleteTarget')
DescribeNotificationRule = Action('DescribeNotificationRule')
ListEventTypes = Action('ListEventTypes')
ListNotificationRules = Action('ListNotificationRules')
ListTagsForResource = Action('ListTagsForResource')
ListTargets = Action('ListTargets')
Subscribe = Action('Subscribe')
TagResource = Action('TagResource')
Unsubscribe = Action('Unsubscribe')
UntagResource = Action('UntagResource')
UpdateNotificationRule = Action('UpdateNotificationRule')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Glue DataBrew'
prefix = 'databrew'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDeleteRecipeVersion = Action('BatchDeleteRecipeVersion')
CreateDataset = Action('CreateDataset')
CreateProfileJob = Action('CreateProfileJob')
CreateProject = Action('CreateProject')
CreateRecipe = Action('CreateRecipe')
CreateRecipeJob = Action('CreateRecipeJob')
CreateSchedule = Action('CreateSchedule')
DeleteDataset = Action('DeleteDataset')
DeleteJob = Action('DeleteJob')
DeleteProject = Action('DeleteProject')
DeleteRecipeVersion = Action('DeleteRecipeVersion')
DeleteSchedule = Action('DeleteSchedule')
DescribeDataset = Action('DescribeDataset')
DescribeJob = Action('DescribeJob')
DescribeJobRun = Action('DescribeJobRun')
DescribeProject = Action('DescribeProject')
DescribeRecipe = Action('DescribeRecipe')
DescribeSchedule = Action('DescribeSchedule')
ListDatasets = Action('ListDatasets')
ListJobRuns = Action('ListJobRuns')
ListJobs = Action('ListJobs')
ListProjects = Action('ListProjects')
ListRecipeVersions = Action('ListRecipeVersions')
ListRecipes = Action('ListRecipes')
ListSchedules = Action('ListSchedules')
ListTagsForResource = Action('ListTagsForResource')
PublishRecipe = Action('PublishRecipe')
SendProjectSessionAction = Action('SendProjectSessionAction')
StartJobRun = Action('StartJobRun')
StartProjectSession = Action('StartProjectSession')
StopJobRun = Action('StopJobRun')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDataset = Action('UpdateDataset')
UpdateProfileJob = Action('UpdateProfileJob')
UpdateProject = Action('UpdateProject')
UpdateRecipe = Action('UpdateRecipe')
UpdateRecipeJob = Action('UpdateRecipeJob')
UpdateSchedule = Action('UpdateSchedule')
